@@ -2,7 +2,7 @@ from abc import ABCMeta, abstractmethod
 
 from meiga import Result, Error, NotImplementedMethodError
 
-from petisco.application.interface_application_service import IAppService
+from petisco.application.interface_app_service import IAppService
 
 
 class ISumExecutor(IAppService):
